@@ -9,11 +9,13 @@ from datetime import datetime
 from email.message import Message
 from email.utils import parsedate_to_datetime
 from pathlib import Path
-from typing import Generator, List, Optional, Union
+from typing import Generator, List, Optional, Tuple, Union
 
 from treelib import Tree
 
 from libratom.lib.base import Archive, AttachmentMetadata
+from libratom.lib.constants import BodyType
+from libratom.lib.utils import guess_mime_type
 
 
 class MboxArchive(Archive):
@@ -73,6 +75,21 @@ class MboxArchive(Archive):
 
         return ""
 
+    @staticmethod
+    def get_message_body(message: Message) -> Tuple[str, Optional[BodyType]]:
+        """
+        Returns the message body along with a plain body type
+        """
+        return MboxArchive.format_message(message), BodyType.PLAIN
+
+    @staticmethod
+    def get_message_headers(message: Message) -> str:
+        """
+        Returns the message headers as one multiline string
+        """
+
+        return "\n".join([f"{key}: {value}" for key, value in message.items()])
+
     def get_attachment_metadata(self, message: Message) -> List[AttachmentMetadata]:
         """
         Returns the metadata of all attachments in a given message
@@ -81,7 +98,8 @@ class MboxArchive(Archive):
         return [
             AttachmentMetadata(
                 name=part.get_filename(),
-                mime_type=part.get_content_type(),
+                mime_type=part.get_content_type()
+                or guess_mime_type(part.get_filename()),
                 size=len(part.get_payload()),
             )
             for part in message.walk()
@@ -105,13 +123,15 @@ class MboxArchive(Archive):
         # Set up children
         for i, message in enumerate(self.messages(), start=1):
             self._tree.create_node(
-                f"Message index: {i}", i, parent=0, data=message,
+                f"Message index: {i}",
+                i,
+                parent=0,
+                data=message,
             )
 
     @property
     def tree(self) -> Tree:
-        """Returns the object's internal tree structure
-        """
+        """Returns the object's internal tree structure"""
 
         try:
             return self._tree
